#!/usr/bin/perl -w
###############################################################################
# print.pl - this code displays the story ready to print
#
# based on code Copyright (C) 2001 Norbert "Momo_102" Kuemin
#	<momo_102@bluemail.ch>
#
# modified and ported to Slash 2.2 Fry beta in October 2001 
#	by chromatic <chromatic@wgz.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###############################################################################

use strict;
use Slash;
use Slash::Display;
use Slash::Utility;
use vars qw( $VERSION );
$VERSION = '1.13';

main();
return;

sub main {
	my $form		= getCurrentForm();
	my $user		= getCurrentUser;
	my $slashdb		= getCurrentDB();
	my $constants	= getCurrentStatic();

	# XXX - could we loop over several SIDs?
	my $sid = $form->{sid};

	# story id must exist
	# story must be viewable for a non-author or non-admin to view it
	unless ($sid && (($user->{author} || $user->{is_admin}) ||
	$slashdb->checkStoryViewable($sid))) {
		redirect($constants->{rootdir});
		return;
	}

	my $sect_title = $user->{currentSection}{title};

	my $story	= $slashdb->getStory($sid);
	my $topic	= $slashdb->getTopic($story->{tid});
	my $author	= $slashdb->getAuthor($story->{uid},
		[qw( nickname fakeemail homepage )]);

	$story->{storytime} = timeCalc($story->{time});

	(my $adm, $user->{is_admin}) = ($user->{is_admin}, 0);

	header($sect_title);
	$user->{is_admin} = $adm;

	slashDisplay('dispStory', {
		user			=> $user,
		story			=> $story,
		topic			=> $topic,
		author			=> $author,
		section			=> $sect_title,
		displayLinks	=> !$form->{nohtml},
	}, { Nocomm => 1 });

	slashDisplay('footer', {
		time			=> $slashdb->getTime(),
		story			=> $story,
		displayLinks	=> !$form->{nohtml},
		autoPrint		=> $form->{auto},
	}, { Nocomm => 1 });
}
